@@ -58,7 +58,7 @@ static void gx_selector_get_property(
 static gboolean gx_selector_value_entry(GxRegler *regler, GdkRectangle *rect, GdkEventButton *event);
 static void gx_selector_style_updated(GtkWidget *widget);
 
-G_DEFINE_TYPE_WITH_PRIVATE(GxSelector, gx_selector, GX_TYPE_REGLER);
+G_DEFINE_TYPE_WITH_PRIVATE(GxSelector, gx_selector, GX_TYPE_REGLER)
 
 static void gx_selector_class_init(GxSelectorClass *klass)
 {
