@@ -17,53 +17,9 @@
  * --------------------------------------------------------------------------
  */
 
-#include <glibmm.h>
+#include <atomic>
 #include "gx_common.h"
 
-/****************************************************************
- ** "atomic" value access
- */
-
-inline void atomic_set(volatile int32_t* p, int32_t v)
-{
-  g_atomic_int_set(p, v);
-}
-
-inline int32_t atomic_get(volatile int32_t& p)
-{
-  return g_atomic_int_get(&p);
-}
-
-inline bool atomic_compare_and_exchange(volatile int32_t *p, int32_t oldv, int32_t newv)
-{
-  return g_atomic_int_compare_and_exchange(p, oldv, newv);
-}
-
-template <class T>
-inline void atomic_set(T **p, T *v)
-{
-  g_atomic_pointer_set(p, v);
-}
-
-template <class T>
-inline void atomic_set_0(T **p)
-{
-  g_atomic_pointer_set(p, 0);
-}
-
-template <class T>
-inline T *atomic_get(T*& p)
-{
-  return static_cast<T*>(g_atomic_pointer_get(&p));
-}
-
-template <class T>
-inline bool atomic_compare_and_exchange(T **p, T *oldv, T *newv)
-{
-  return g_atomic_pointer_compare_and_exchange(reinterpret_cast<void* volatile*>(p), oldv, newv);
-}
-
-
 #include "gxamp.h"
 #include "gx_resampler.h"
 #include "gx_convolver.h"
@@ -102,6 +58,7 @@ declare(gxamp15);
 declare(gxamp16);
 declare(gxamp17);
 declare(gxamp18);
+declare(gxnoamp);
 
 static plug amp_model [] = {
     gxamp::plugin, //0
@@ -126,6 +83,8 @@ static plug amp_model [] = {
     gxamp8::plugin, //15
     gxamp16::plugin, //16
     gxamp6::plugin, //17
+
+    gxnoamp::plugin, //18
 };
 
 static const size_t AMP_COUNT = sizeof(amp_model) / sizeof(amp_model[0]);
@@ -236,12 +195,14 @@ private:
   bool                         doit;
   float*                       schedule_ok;
   float                        schedule_ok_;
-  volatile int32_t             schedule_wait;
+  std::atomic<bool>            _execute;
 
   inline bool cab_changed() 
     {return std::abs(cab - clevel_ ) > 0.1;}
   inline bool buffsize_changed() 
     {return bufsize != cur_bufsize;}
+  inline bool IsPowerOfTwo(uint32_t x)
+    {return (x >= 64) && ((x & (x - 1)) == 0);}
   inline void update_cab() 
     {cab = clevel_ ; c_old_model_ = c_model_;}
   inline bool change_cab() 
@@ -326,7 +287,7 @@ GxPluginMono::GxPluginMono() :
   schedule_ok(NULL),
   schedule_ok_(0)
 {
-  atomic_set(&schedule_wait,0);
+
 };
   // destructor
 GxPluginMono::~GxPluginMono()
@@ -341,9 +302,8 @@ GxPluginMono::~GxPluginMono()
 
 void GxPluginMono::do_work_mono()
 {
-  
-  if (buffsize_changed()) 
-   {
+  if (buffsize_changed() && IsPowerOfTwo(cur_bufsize)) 
+  {
      printf("buffersize changed to %u\n",cur_bufsize);
      if (cabconv.is_runnable())
         {
@@ -356,7 +316,6 @@ void GxPluginMono::do_work_mono()
           ampconv.stop_process();
         }
      bufsize = cur_bufsize;
-
 	 cabconv.cleanup();
      CabDesc& cab = *getCabEntry(static_cast<uint32_t>(c_model_)).data;
      cabconv.cab_count = cab.ir_count;
@@ -372,7 +331,6 @@ void GxPluginMono::do_work_mono()
      while (!cabconv.checkstate());
      if(!cabconv.start(prio, SCHED_FIFO))
         printf("cabinet convolver update buffersize fail\n");
-
      ampconv.cleanup();
      ampconv.set_samplerate(s_rate);
      ampconv.set_buffersize(bufsize);
@@ -382,7 +340,7 @@ void GxPluginMono::do_work_mono()
      while (!ampconv.checkstate());
      if(!ampconv.start(prio, SCHED_FIFO))
         printf("presence convolver update buffersize fail\n");
-   }
+  }
   if (cab_changed() || change_cab())
     {
       if (cabconv.is_runnable())
@@ -434,7 +392,7 @@ void GxPluginMono::do_work_mono()
         printf("presence convolver disabled\n");
       update_pre();
     }
-  atomic_set(&schedule_wait,0);
+  _execute.store(false, std::memory_order_release);
 }
 
 void GxPluginMono::init_dsp_mono(uint32_t rate, uint32_t bufsize_)
@@ -491,6 +449,7 @@ void GxPluginMono::init_dsp_mono(uint32_t rate, uint32_t bufsize_)
       printf("convolver disabled\n");
       schedule_ok_ = 1.;
     }
+    _execute.store(false, std::memory_order_release);
 }
 
 
@@ -556,7 +515,8 @@ void GxPluginMono::run_dsp_mono(uint32_t n_samples)
     a_model_ = min(a_max, static_cast<uint32_t>(*(a_model)));
     amplifier[a_model_]->mono_audio(static_cast<int>(n_samples), input, output, amplifier[a_model_]);
     // run presence convolver
-    ampconv.run_static(n_samples, &ampconv, output);
+    if (*(alevel) >= 1.0)
+        ampconv.run_static(n_samples, &ampconv, output);
     // run selected tonestack
     t_model_ =  static_cast<uint32_t>(*(t_model));
     if (t_model_<=t_max)
@@ -568,12 +528,12 @@ void GxPluginMono::run_dsp_mono(uint32_t n_samples)
 
   MXCSR.reset_();
   // work ?
-  if (!atomic_get(schedule_wait) && (val_changed() || buffsize_changed())) 
+  if (!_execute.load(std::memory_order_acquire) && (val_changed() || buffsize_changed())) 
     {
       clevel_ = (*clevel);
       alevel_ = (*alevel);
       c_model_= (*c_model);
-      atomic_set(&schedule_wait,1);
+      _execute.store(true, std::memory_order_release);
       schedule->schedule_work(schedule->handle, sizeof(bool), &doit);
     }
 }
@@ -672,7 +632,7 @@ LV2_Handle GxPluginMono::instantiate(const LV2_Descriptor*     descriptor,
   if (!self->schedule)
     {
       fprintf(stderr, "Missing feature work:schedule.\n");
-      atomic_set(&self->schedule_wait,1);
+      self->_execute.store(true, std::memory_order_release);
       self->schedule_ok_ = 1.;
       //delete self;
       //return NULL;
@@ -682,14 +642,10 @@ LV2_Handle GxPluginMono::instantiate(const LV2_Descriptor*     descriptor,
   if (!self->map)
     {
       fprintf(stderr, "Missing feature uri:map.\n");
-      //atomic_set(&self->schedule_wait,1);
-      //self->schedule_ok_ = 1.;
     }
   else if (!options)
     {
       fprintf(stderr, "Missing feature options.\n");
-      //atomic_set(&self->schedule_wait,1);
-     // self->schedule_ok_ = 1.;
     }
   else
     {
@@ -717,8 +673,6 @@ LV2_Handle GxPluginMono::instantiate(const LV2_Descriptor*     descriptor,
       if (bufsize == 0)
         {
           fprintf(stderr, "No maximum buffer size given.\n");
-          //atomic_set(&self->schedule_wait,1);
-          //self->schedule_ok_ = 1.;
         }
       printf("using block size: %d\n", bufsize);
       self->schedule_ok_ = 0.;
@@ -781,9 +735,6 @@ const LV2_Descriptor GxPluginMono::descriptor =
   extension_data
 };
 
-#ifdef __cplusplus
-extern "C" {
-#endif
 LV2_SYMBOL_EXPORT
 const LV2_Descriptor*
 lv2_descriptor(uint32_t index)
@@ -796,6 +747,3 @@ lv2_descriptor(uint32_t index)
       return NULL;
     }
 }
-#ifdef __cplusplus
-}
-#endif
