@@ -17,59 +17,17 @@
  * --------------------------------------------------------------------------
  */
 
-#include <glibmm.h>
+#include <atomic>
 #include "gx_common.h"
 
-/****************************************************************
- ** "atomic" value access
- */
-
-inline void atomic_set(volatile int32_t* p, int32_t v)
-{
-  g_atomic_int_set(p, v);
-}
-
-inline int32_t atomic_get(volatile int32_t& p)
-{
-  return g_atomic_int_get(&p);
-}
-
-inline bool atomic_compare_and_exchange(volatile int32_t *p, int32_t oldv, int32_t newv)
-{
-  return g_atomic_int_compare_and_exchange(p, oldv, newv);
-}
-
-template <class T>
-inline void atomic_set(T **p, T *v)
-{
-  g_atomic_pointer_set(p, v);
-}
-
-template <class T>
-inline void atomic_set_0(T **p)
-{
-  g_atomic_pointer_set(p, 0);
-}
-
-template <class T>
-inline T *atomic_get(T*& p)
-{
-  return static_cast<T*>(g_atomic_pointer_get(&p));
-}
-
-template <class T>
-inline bool atomic_compare_and_exchange(T **p, T *oldv, T *newv)
-{
-  return g_atomic_pointer_compare_and_exchange(reinterpret_cast<void* volatile*>(p), oldv, newv);
-}
-
-
 #include "gxamp_stereo.h"
 #include "gx_resampler.h"
 #include "gx_convolver.h"
 #include "gx_pluginlv2.h"   // define struct PluginLV2
 #include "impulse_former.h"
 #include "ampulse_former.h"
+#include "gx_bypass.cc"     // bypass ramping
+
 #ifndef __SSE__
 #include "stereo_noiser.cc"
 #endif
@@ -99,6 +57,7 @@ declare(gxamp15_stereo);
 declare(gxamp16_stereo);
 declare(gxamp17_stereo);
 declare(gxamp18_stereo);
+declare(gxnoamp_stereo);
 
 static plug amp_model [] = {
     gxamp_stereo::plugin, //0
@@ -123,6 +82,8 @@ static plug amp_model [] = {
     gxamp8_stereo::plugin, //15
     gxamp16_stereo::plugin, //16
     gxamp6_stereo::plugin, //17
+
+    gxnoamp_stereo::plugin, //18
 };
 
 static const size_t AMP_COUNT = sizeof(amp_model) / sizeof(amp_model[0]);
@@ -192,6 +153,9 @@ static const size_t TS_COUNT = sizeof(tonestack_model) / sizeof(tonestack_model[
 class GxPluginStereo
 {
 private:
+  GxBypass                     bp;
+  float*                       bypass;
+  DenormalProtection           MXCSR;
   // internal stuff
   float*                       output;
   float*                       output1;
@@ -232,12 +196,14 @@ private:
   bool                         doit;
   float*                       schedule_ok;
   float                        schedule_ok_;
-  volatile int32_t             schedule_wait;
+  std::atomic<bool>            _execute;
   
   bool cab_changed()
     {return std::abs(cab - clevel_ ) > 0.1;}
-  bool buffsize_changed() 
+  inline bool buffsize_changed() 
     {return bufsize != cur_bufsize;}
+  inline bool IsPowerOfTwo(uint32_t x)
+    {return (x >= 64) && ((x & (x - 1)) == 0);}
   void update_cab()
     {cab = (clevel_ ); c_old_model_ = c_model_;}
   bool change_cab()
@@ -293,6 +259,9 @@ public:
 
 // constructor
 GxPluginStereo::GxPluginStereo() :
+  bp(),
+  bypass(0),
+  MXCSR(),
   output(NULL),
   output1(NULL),
   input(NULL),
@@ -323,7 +292,6 @@ GxPluginStereo::GxPluginStereo() :
   schedule_ok(NULL),
   schedule_ok_(0)
 {
-  atomic_set(&schedule_wait,0);
 };
   
 // destructor
@@ -340,8 +308,8 @@ GxPluginStereo::~GxPluginStereo()
 
 void GxPluginStereo::do_work_stereo()
 {
-  if (buffsize_changed()) 
-   {
+  if (buffsize_changed() && IsPowerOfTwo(cur_bufsize)) 
+  {
      printf("buffersize changed to %u\n",cur_bufsize);
      if (cabconv.is_runnable())
         {
@@ -380,7 +348,7 @@ void GxPluginStereo::do_work_stereo()
      while (!ampconv.checkstate());
      if(!ampconv.start(prio, SCHED_FIFO))
         printf("presence convolver update buffersize fail\n");
-   }
+  }
   if (cab_changed() || change_cab())
     {
       if (cabconv.is_runnable())
@@ -434,15 +402,14 @@ void GxPluginStereo::do_work_stereo()
       update_pre();
       //printf("presence convolver updated\n");
     }
-  atomic_set(&schedule_wait,0);
+  _execute.store(false, std::memory_order_release);
 }
 
 void GxPluginStereo::init_dsp_stereo(uint32_t rate, uint32_t bufsize_)
 {
-  AVOIDDENORMALS();
-
   bufsize = bufsize_;
   s_rate = rate;
+  bp.init_bypass(rate);
 
 #ifdef _POSIX_MEMLOCK_RANGE
   GX_LOCK::lock_rt_memory();
@@ -492,6 +459,7 @@ void GxPluginStereo::init_dsp_stereo(uint32_t rate, uint32_t bufsize_)
     {
       printf("convolver disabled\n");
     }
+    _execute.store(false, std::memory_order_release);
 }
 
 
@@ -535,6 +503,9 @@ void GxPluginStereo::connect_stereo(uint32_t port,void* data)
     case AMP_INPUT1:
       input1 = static_cast<float*>(data);
       break;
+    case BYPASS: 
+      bypass = static_cast<float*>(data); // , 0.0, 0.0, 1.0, 1.0 
+      break;
     default:
       break;
     }
@@ -543,31 +514,45 @@ void GxPluginStereo::connect_stereo(uint32_t port,void* data)
 void GxPluginStereo::run_dsp_stereo(uint32_t n_samples)
 {
   if (n_samples< 1) return;
+  MXCSR.set_();
   cur_bufsize = n_samples;
   if (*(schedule_ok) != schedule_ok_) *(schedule_ok) = schedule_ok_;
   // run dsp
+  FAUSTFLOAT buf[n_samples];
+  FAUSTFLOAT buf1[n_samples];
+  // do inplace processing at default
+  if (output != input)
+    memcpy(output, input, n_samples*sizeof(float));
+  if (output1 != input1)
+    memcpy(output1, input1, n_samples*sizeof(float));
+  // check if bypass is pressed
+  if (!bp.pre_check_bypass(bypass, buf, buf1, input, input1, n_samples)) {
 #ifndef __SSE__
-  wn->stereo_audio(static_cast<int>(n_samples), input, input1, input, input1, wn);;
+    wn->stereo_audio(static_cast<int>(n_samples), input, input1, input, input1, wn);;
 #endif
-  // run selected tube model
-  a_model_ = min(a_max, static_cast<uint32_t>(*(a_model)));
-  amplifier[a_model_]->stereo_audio(static_cast<int>(n_samples), input, input1, output, output1, amplifier[a_model_]);
-  // run presence convolver
-  ampconv.run_static_stereo(n_samples, &ampconv, output, output1);
-  // run selected tonestack
-  t_model_ = static_cast<uint32_t>(*(t_model));
-  if (t_model_ <= t_max)
-  tonestack[t_model_]->stereo_audio(static_cast<int>(n_samples), output, output1, output, output1, tonestack[t_model_]);
-  // run selected cabinet convolver
-  cabconv.run_static_stereo(n_samples, &cabconv, output, output1);
+    // run selected tube model
+    a_model_ = min(a_max, static_cast<uint32_t>(*(a_model)));
+    amplifier[a_model_]->stereo_audio(static_cast<int>(n_samples), input, input1, output, output1, amplifier[a_model_]);
+    // run presence convolver
+    if (*(alevel) >= 1.0)
+        ampconv.run_static_stereo(n_samples, &ampconv, output, output1);
+    // run selected tonestack
+    t_model_ = static_cast<uint32_t>(*(t_model));
+    if (t_model_ <= t_max)
+    tonestack[t_model_]->stereo_audio(static_cast<int>(n_samples), output, output1, output, output1, tonestack[t_model_]);
+    // run selected cabinet convolver
+    cabconv.run_static_stereo(n_samples, &cabconv, output, output1);
+  }
+  bp.post_check_bypass(buf, buf1, output, output1, n_samples);
 
+  MXCSR.reset_();
   // work ?
-  if (!atomic_get(schedule_wait) && (val_changed() || buffsize_changed() ))
+  if (!_execute.load(std::memory_order_acquire) && (val_changed() || buffsize_changed()) )
     {
       clevel_ = (*clevel);
       alevel_ = (*alevel);
       c_model_= (*c_model);
-      atomic_set(&schedule_wait,1);
+      _execute.store(true, std::memory_order_release);
       schedule->schedule_work(schedule->handle, sizeof(bool), &doit);
     }
 }
@@ -670,7 +655,7 @@ GxPluginStereo::instantiate(const LV2_Descriptor*     descriptor,
   if (!self->schedule)
     {
       fprintf(stderr, "Missing feature work:schedule.\n");
-      atomic_set(&self->schedule_wait,1);
+      self->_execute.store(true, std::memory_order_release);
       self->schedule_ok_ = 1;
       //delete self;
       //return NULL;
@@ -678,14 +663,10 @@ GxPluginStereo::instantiate(const LV2_Descriptor*     descriptor,
   if (!self->map)
     {
       fprintf(stderr, "Missing feature uri:map.\n");
-      //atomic_set(&self->schedule_wait,1);
-      //self->schedule_ok_ = 1;
     }
   else if (!options)
     {
       fprintf(stderr, "Missing feature options.\n");
-      //atomic_set(&self->schedule_wait,1);
-      //self->schedule_ok_ = 1;
     }
   else
     {
@@ -713,8 +694,6 @@ GxPluginStereo::instantiate(const LV2_Descriptor*     descriptor,
       if (bufsize == 0)
         {
           fprintf(stderr, "No maximum buffer size given.\n");
-          //atomic_set(&self->schedule_wait,1);
-          //self->schedule_ok_ = 1;
       }
       printf("using block size: %d\n", bufsize);
     }
@@ -776,7 +755,6 @@ const LV2_Descriptor GxPluginStereo::descriptor =
   extension_data
 };
 
-extern "C"
 LV2_SYMBOL_EXPORT
 const LV2_Descriptor*
 lv2_descriptor(uint32_t index)
