@@ -302,13 +302,16 @@ GxEngine::GxEngine(const string& plugin_dir, ParameterGroups& groups, const gx_s
       detune(*this, sigc::mem_fun(mono_chain, &MonoModuleChain::sync)) {
     set_overload_interval(options.get_sporadic_overload());
     if (!options.get_convolver_watchdog()) {
-	ov_disabled |= ov_Convolver;
+        ov_disabled |= ov_Convolver;
+    }
+    if (!options.get_watchdog_warning()) {
+        ov_disabled |= ov_NoWarn;
     }
     if (!options.get_xrun_watchdog()) {
-	ov_disabled |= ov_XRun;
+        ov_disabled |= ov_XRun;
     }
     if (options.get_mute()) {
-	set_state(kEngineOff);;
+        set_state(kEngineOff);;
     }
 #ifdef USE_MIDI_OUT
     tuner.set_dep_module(&midiaudiobuffer.plugin);
@@ -379,6 +382,7 @@ void GxEngine::load_static_plugins() {
     pl.add(gx_effects::gx_outputlevel::plugin(),  PLUGIN_POS_END);
     pl.add(balance::plugin(),                     PLUGIN_POS_END, PGN_MODE_BYPASS);
     pl.add(&stereomute,                           PLUGIN_POS_END, PGN_MODE_MUTE);
+    pl.add(fizz_remover::plugin(),                PLUGIN_POS_END, PGN_GUI);
     pl.add(hardlim::plugin(),                     PLUGIN_POS_END, PGN_MODE_NORMAL);
     pl.add(&drumout.outputdrum,                   PLUGIN_POS_END, PGN_MODE_NORMAL);
     pl.add(&directout,                            PLUGIN_POS_END, PGN_MODE_NORMAL);
