@@ -696,6 +696,9 @@ void __rt_func ModuleSequencer::overload(OverloadType tp, const char *reason) {
     if ((tp & ov_disabled) == ov_XRun) {
 	return; // the xrun should show up in the log anyhow
     }
+    if ((tp & ov_disabled) == ov_NoWarn) {
+	return; // overload messages been switched off 
+    }
     bool ignore = false;
     if ((tp & ov_disabled) == ov_Convolver) {
 	ignore = true;
@@ -750,7 +753,7 @@ void ModuleSequencer::check_overload() {
 	gx_print_error(
 	    "watchdog",
 	    boost::format(_("Overload (%s)")) % gx_system::atomic_get(overload_reason));
-    } else {
+    } else if ((ov_disabled & ov_NoWarn) == 0) {
 	gx_print_error(
 	    "watchdog",
 	    boost::format(_("Overload ignored (%s)")) % gx_system::atomic_get(overload_reason));
