@@ -221,7 +221,7 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
         {"Augmented Fourths"},{"Slow Motion"},{"Admiral"},{"Buzzard"},{"Face"},{"Four and Twenty"},{"Ostrich"},{"Capo 200"},
         {"Balalaika"},{"Cittern One"},{"Cittern Two"},{"Dobro"},{"Lefty"},{"Mandoguitar"},{"Rusty Cage"},{"Hardcore"}, {0}};
     pmap.reg_non_midi_enum_par("racktuner.tuning", "Tuning", tuning_labels, (int*)0, false, 0);
-    static const value_pair tuning_temperament[] = {{"12-ET"},{"19-ET"},{"24-ET"},{"31-ET"},{"53-ET"}, {0}};
+    static const value_pair tuning_temperament[] = {{"12-ET"},{"19-ET"},{"24-ET"},{"31-ET"},{"41-ET"},{"53-ET"}, {0}};
     pmap.reg_non_midi_enum_par("racktuner.temperament", "Temperament", tuning_temperament, (int*)0, false, 0);
     pmap.reg_par_non_preset("racktuner.scale_lim", "Limit", 0, 3.0, 1.0, 10.0, 1.0);
     pmap.reg_par_non_preset("ui.tuner_reference_pitch", "?Tuner Reference Pitch", 0, 440, 225, 453, 0.1);
@@ -694,6 +694,10 @@ void GxMachine::disable_autosave(bool v) {
     settings.disable_autosave(v);
 }
 
+void GxMachine::disable_save_on_exit(bool v) {
+    settings.disable_save_on_exit(v);
+}
+
 sigc::signal<void>& GxMachine::signal_selection_changed() {
     return settings.signal_selection_changed();
 }
@@ -1018,6 +1022,14 @@ void GxMachine::midi_feedback(int c, int v) {
 #endif
 }
 
+bool GxMachine::get_midi_feedback() {
+    return options.system_midiout;
+}
+
+void GxMachine::set_midi_feedback(int v) {
+    options.system_midiout = v;
+}
+
 // Convolver
 
 void GxMachine::on_impresp(const std::string& path) {
@@ -2238,6 +2250,11 @@ void GxMachineRemote::disable_autosave(bool v) {
     /* noop */
 }
 
+void GxMachineRemote::disable_save_on_exit(bool v) {
+    //FIXME: move inside machine
+    /* noop */
+}
+
 sigc::signal<void>& GxMachineRemote::signal_selection_changed() {
     return selection_changed;
 }
@@ -2883,6 +2900,22 @@ void GxMachineRemote::midi_feedback(int c, int v) {
 #endif
 }
 
+bool GxMachineRemote::get_midi_feedback() {
+    START_CALL(get_midi_feedback);
+    START_RECEIVE(false);
+    jp->next(gx_system::JsonParser::begin_object);
+    jp->next(gx_system::JsonParser::value_number);
+    return jp->current_value_int();
+    END_RECEIVE(return false);
+    
+}
+
+void GxMachineRemote::set_midi_feedback(int v) {
+    START_NOTIFY(set_midi_feedback);
+    jw->write(v);
+    SEND();
+}
+
 // Convolver
 
 void GxMachineRemote::reload_impresp_list(const std::string& path) {
