@@ -112,7 +112,11 @@ inline void atomic_inc(volatile unsigned int* p) {
 }
 
 inline bool atomic_compare_and_exchange(volatile int *p, int oldv, int newv) {
+#if (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 68 && GLIB_MICRO_VERSION < 1)
     return g_atomic_int_compare_and_exchange(p, oldv, newv);
+#else
+    return g_atomic_int_compare_and_exchange(const_cast<int*>(p), oldv, newv);
+#endif
 }
 
 template <class T>
@@ -132,7 +136,7 @@ inline T *atomic_get(T*& p) {
 
 template <class T>
 inline bool atomic_compare_and_exchange(T **p, T *oldv, T *newv) {
-    return g_atomic_pointer_compare_and_exchange(reinterpret_cast<void* volatile*>(p), static_cast<void*>(oldv), newv);
+    return g_atomic_pointer_compare_and_exchange(reinterpret_cast<void**>(p), static_cast<void*>(oldv), newv);
 }
 
 
@@ -428,6 +432,7 @@ private:
     int sporadic_overload;
     int idle_thread_timeout;
     bool convolver_watchdog;
+    bool watchdog_warning;
     bool xrun_watchdog;
     bool lterminal;
     bool a_save;
@@ -459,6 +464,7 @@ public:
     bool system_show_toolbar;
     bool system_show_rack;
     bool system_midiout;
+    bool system_tuner_midiout;
     bool reload_lv2_presets;
 
 public:
@@ -535,6 +541,7 @@ public:
     int get_sporadic_overload() const { return sporadic_overload; }
     bool get_xrun_watchdog() const { return xrun_watchdog; }
     bool get_convolver_watchdog() const { return convolver_watchdog; }
+    bool get_watchdog_warning() const { return watchdog_warning; }
 };
 
 inline BasicOptions& get_options() {
