@@ -24,9 +24,9 @@
 
 #include "engine.h"
 #include <bitset>
+#include <queue>
 #include <giomm/init.h>     // NOLINT
 #include <giomm/socketservice.h>
-//#include <ext/stdio_filebuf.h>
 #include "jsonrpc_methods.h"
 
 class GxService;
@@ -68,9 +68,6 @@ public:
 	f_log_message,
 	f_midi_changed,
 	f_midi_value_changed,
-	f_osc_activation,
-	f_osc_size_changed,
-	f_jack_load_changed,
 	f_parameter_change_notify,
 	f_plugins_changed,
 	f_misc_msg,
@@ -85,7 +82,7 @@ private:
     gx_system::JsonStringParser jp;
     bool midi_config_mode;
     std::bitset<END_OF_FLAGS> flags;
-    float maxlevel[gx_engine::MaxLevel::channelcount];
+    std::map<string,float> maxlevel;
 private:
     bool find_token(const Glib::ustring& token, msg_type *start, msg_type *end);
     void activate(int n, bool v) { flags.set(n, v); }
@@ -110,10 +107,16 @@ public:
     bool on_data_out(Glib::IOCondition cond);
     void send(gx_system::JsonStringWriter& jw);
     bool is_activated(msg_type n) { return flags[n]; }
-    void update_maxlevel(unsigned int channel, float v) { maxlevel[channel] = max(maxlevel[channel], v); }
+    void update_maxlevel(const std::string& id, float v) { float& m = maxlevel[id]; m = max(m, v); }
     friend class UiBuilderVirt;
 };
 
+struct broadcast_data {
+    gx_system::JsonStringWriter *jw;
+    CmdConnection::msg_type n;
+    CmdConnection *sender;
+};
+
 class GxService: public Gio::SocketService {
 private:
     struct ChangedPlugin {
@@ -130,9 +133,10 @@ private:
     time_t last_change;
     sigc::connection save_conn;
     std::list<CmdConnection*> connection_list;
+    std::queue<broadcast_data> broadcast_list;
     gx_system::JsonStringWriter *jwc;
     std::map<std::string,bool> *preg_map;
-    float maxlevel[gx_engine::MaxLevel::channelcount];
+    std::map<std::string,float> maxlevel;
 private:
     virtual bool on_incoming(const Glib::RefPtr<Gio::SocketConnection>& connection,
 			     const Glib::RefPtr<Glib::Object>& source_object);
@@ -140,6 +144,7 @@ private:
     void remove_connection(CmdConnection* p);
     bool broadcast_listeners(CmdConnection::msg_type n, CmdConnection *sender = 0);
     void broadcast(gx_system::JsonStringWriter& jw, CmdConnection::msg_type n, CmdConnection *sender = 0);
+    bool idle_broadcast_handler();
     void connect_value_changed_signal(gx_engine::Parameter *p);
 
     // message formatting functions
@@ -159,9 +164,6 @@ private:
     void on_log_message(const string& msg, GxLogger::MsgType tp, bool plugged);
     void on_midi_changed();
     void on_midi_value_changed(int ctl, int value);
-    void on_osc_size_changed(unsigned int sz);
-    int on_osc_activation(bool v);
-    void on_jack_load_changed();
     void on_rack_unit_changed(bool stereo);
     static void add_changed_plugin(gx_engine::Plugin* pl, gx_engine::PluginChange::pc v,
 				   std::vector<ChangedPlugin>& vec);
@@ -175,13 +177,7 @@ public:
     ~GxService();
     void send_rack_changed(bool stereo, CmdConnection *cmd);
     void ladspaloader_update_plugins(gx_system::JsonWriter *jw, CmdConnection *cmd);
-    void update_maxlevel(CmdConnection *cmd = 0);
-    float get_maxlevel(unsigned int channel) {
-	assert(channel < gx_engine::MaxLevel::channelcount);
-	float v = maxlevel[channel];
-	maxlevel[channel] = 0;
-	return v;
-    }
+    float update_maxlevel(const std::string& id, bool reset=false);
 };
 
 const char *engine_state_to_string(gx_engine::GxEngineState s);
