@@ -167,6 +167,10 @@ def configure(conf):
         if conf.env['NOOPT']:
             conf.env['OPT'] = False
             cpu_model = append_optimization_flags(conf, cxxflags)
+
+    if '-flto' in cxxflags:
+        cxxflags.append ("-ffat-lto-objects")
+
     cxxflags.append ("-std=c++11")
     conf.env['CXXFLAGS'] += cxxflags
     conf.cpu_model = cpu_model
